==> resolwe-bio-9.0.0a2.tar.gz: resolwe-bio-9.0.0a2/resolwe_bio/tests/processes/test_chipseq.py <==
# pylint: disable=missing-docstring
from os.path import join

from resolwe.test import tag_process
from resolwe_bio.utils.test import BioProcessTestCase, skipUnlessLargeFiles


class ChipSeqProcessorTestCase(BioProcessTestCase):

    @tag_process('chipseq-peakscore', 'chipseq-genescore')
    def test_chipseq(self):
        with self.preparation_stage():
            inputs = {
                'src': 'chip_seq_control.bam',
                'species': 'Dictyostelium discoideum',
                'build': 'dd-05-2009'
            }
            control_bam = self.run_process("upload-bam", inputs)

            inputs = {
                'src': 'chip_seq_case.bam',
                'species': 'Dictyostelium discoideum',
                'build': 'dd-05-2009'
            }
            case_bam = self.run_process("upload-bam", inputs)

            inputs = {
                'src': 'chip_seq.bed',
                'species': 'Dictyostelium discoideum',
                'build': 'dd-05-2009'
            }
            bed = self.run_process('upload-bed', inputs)

            inputs = {
                'case': case_bam.pk,
                'control': control_bam.pk,
                'settings': {'nomodel': True,
                             'gsize': '3.4e7',
                             'pvalue': 0.001,
                             'slocal': 2000,
                             'extsize': 100,
                             'call_summits': True}}
            macs2 = self.run_process("macs2-callpeak", inputs)

        inputs = {
            'peaks': macs2.pk,
            'bed': bed.pk}
        peak_score = self.run_process('chipseq-peakscore', inputs)
        self.assertFile(peak_score, 'peak_score', 'chip_seq_peakscore_genomicContext')

        inputs = {'peakscore': peak_score.id}
        gene_score = self.run_process('chipseq-genescore', inputs)
        self.assertFile(gene_score, 'genescore', 'chip_seq_geneScore.xls')

    @tag_process('macs14')
    def test_macs14(self):
        with self.preparation_stage():
            inputs = {
                'src': 'macs14_control.bam',
                'species': 'Homo sapiens',
                'build': 'hg19'
            }
            control_bam = self.run_process("upload-bam", inputs)

            inputs = {
                'src': 'macs14_case.bam',
                'species': 'Homo sapiens',
                'build': 'hg19'
            }
            case_bam = self.run_process("upload-bam", inputs)

        inputs = {"treatment": case_bam.id,
                  "control": control_bam.id}
        macs14 = self.run_process("macs14", inputs)

        self.assertFields(macs14, 'species', 'Homo sapiens')
        self.assertFields(macs14, 'build', 'hg19')
        self.assertFile(macs14, 'peaks_bed', 'macs14_peaks.bed')

    @skipUnlessLargeFiles('rose2_case.bam', 'rose2_control.bam')
    @tag_process('rose2')
    def test_rose2(self):
        with self.preparation_stage():
            inputs = {
                'src': join('large', 'rose2_case.bam'),
                'species': 'Homo sapiens',
                'build': 'hg19'
            }
            bam = self.run_process('upload-bam', inputs)

            inputs = {
                'src': join('large', 'rose2_control.bam'),
                'species': 'Homo sapiens',
                'build': 'hg19'
            }
            control = self.run_process("upload-bam", inputs)

            inputs = {
                'src': 'macs14_chr22.bed',
                'species': 'Homo sapiens',
                'build': 'hg19'
            }
            macs_peaks = self.run_process('upload-bed', inputs)

        inputs = {"genome": 'HG19',
                  "input_upload": macs_peaks.id,
                  "rankby": bam.id,
                  "control": control.id,
                  "tss": 2500}
        rose2 = self.run_process("rose2", inputs)

        # remove changing lines from the rose2 output
        def filter_created(line):
            return line.startswith(b'#Created')

        self.assertFile(rose2, 'all_enhancers', 'rose2_enhancer_table.txt', file_filter=filter_created)

==> resolwe-bio-10.0.0a4.tar.gz: resolwe-bio-10.0.0a4/resolwe_bio/tests/processes/test_chipseq.py <==
# pylint: disable=missing-docstring
from os.path import join

from resolwe.test import tag_process
from resolwe_bio.utils.test import BioProcessTestCase, skipUnlessLargeFiles


class ChipSeqProcessorTestCase(BioProcessTestCase):

    @tag_process('chipseq-peakscore', 'chipseq-genescore')
    def test_chipseq(self):
        with self.preparation_stage():
            inputs = {
                'src': 'chip_seq_control.bam',
                'species': 'Dictyostelium discoideum',
                'build': 'dd-05-2009'
            }
            control_bam = self.run_process("upload-bam", inputs)

            inputs = {
                'src': 'chip_seq_case.bam',
                'species': 'Dictyostelium discoideum',
                'build': 'dd-05-2009'
            }
            case_bam = self.run_process("upload-bam", inputs)

            inputs = {
                'src': 'chip_seq.bed',
                'species': 'Dictyostelium discoideum',
                'build': 'dd-05-2009'
            }
            bed = self.run_process('upload-bed', inputs)

            inputs = {
                'case': case_bam.pk,
                'control': control_bam.pk,
                'settings': {'nomodel': True,
                             'gsize': '3.4e7',
                             'pvalue': 0.001,
                             'slocal': 2000,
                             'extsize': 100,
                             'call_summits': True}}
            macs2 = self.run_process("macs2-callpeak", inputs)

        inputs = {
            'peaks': macs2.pk,
            'bed': bed.pk}
        peak_score = self.run_process('chipseq-peakscore', inputs)
        self.assertFile(peak_score, 'peak_score', 'chip_seq_peakscore_genomicContext')

        inputs = {'peakscore': peak_score.id}
        gene_score = self.run_process('chipseq-genescore', inputs)
        self.assertFile(gene_score, 'genescore', 'chip_seq_geneScore.xls')

    @tag_process('macs14')
    def test_macs14(self):
        with self.preparation_stage():
            inputs = {
                'src': 'macs14_control.bam',
                'species': 'Homo sapiens',
                'build': 'hg19'
            }
            control_bam = self.run_process("upload-bam", inputs)

            inputs = {
                'src': 'macs14_case.bam',
                'species': 'Homo sapiens',
                'build': 'hg19'
            }
            case_bam = self.run_process("upload-bam", inputs)

        inputs = {"treatment": case_bam.id,
                  "control": control_bam.id}
        macs14 = self.run_process("macs14", inputs)

        self.assertFields(macs14, 'species', 'Homo sapiens')
        self.assertFields(macs14, 'build', 'hg19')
        self.assertFile(macs14, 'peaks_bed', 'macs14_peaks.bed.gz')
        self.assertFile(macs14, 'peaks_bigbed_igv_ucsc', 'macs14_peaks.bb')
        self.assertFile(macs14, 'peaks_tbi_jbrowse', 'macs14_peaks.gz.tbi')
        self.assertFile(macs14, 'summits_tbi_jbrowse', 'macs14_summits.gz.tbi')
        self.assertFile(macs14, 'treat_bigwig', 'macs14_treat.bw')

    @skipUnlessLargeFiles('rose2_case.bam', 'rose2_control.bam')
    @tag_process('rose2')
    def test_rose2(self):
        with self.preparation_stage():
            inputs = {
                'src': join('large', 'rose2_case.bam'),
                'species': 'Homo sapiens',
                'build': 'hg19'
            }
            bam = self.run_process('upload-bam', inputs)

            inputs = {
                'src': join('large', 'rose2_control.bam'),
                'species': 'Homo sapiens',
                'build': 'hg19'
            }
            control = self.run_process("upload-bam", inputs)

            inputs = {
                'src': 'macs14_chr22.bed',
                'species': 'Homo sapiens',
                'build': 'hg19'
            }
            macs_peaks = self.run_process('upload-bed', inputs)

        inputs = {"genome": 'HG19',
                  "input_upload": macs_peaks.id,
                  "rankby": bam.id,
                  "control": control.id,
                  "tss": 2500}
        rose2 = self.run_process("rose2", inputs)

        # remove changing lines from the rose2 output
        def filter_created(line):
            return line.startswith(b'#Created')

        self.assertFile(rose2, 'all_enhancers', 'rose2_enhancer_table.txt', file_filter=filter_created)
